@@ -2,7 +2,7 @@ import cProfile
 import pstats
 import io
 try:
-    from .variable import variable
+    from pyees.variable import variable
 except ImportError:
     from variable import variable
     
