@@ -162,7 +162,7 @@ class test(unittest.TestCase):
         B = variable(745.1, 'K', uncert=53.9)
         C = A - B
         self.assertAlmostEqual(C.value, 12.3 + 273.15 - 745.1)
-        self.assertEqual(C.unit, 'K')
+        self.assertEqual(C.unit, 'DELTAK')
         self.assertAlmostEqual(C.uncert, np.sqrt(2.6**2 + 53.9**2))
 
         A = variable(12.3, 'C', uncert=2.6)
@@ -312,17 +312,19 @@ class test(unittest.TestCase):
 
         with self.assertRaises(Exception) as context:
             A_vec ** B_vec
-        self.assertTrue('The exponent has to be a single number' in str(context.exception))
+        self.assertTrue('The exponent can not have a unit' in str(context.exception))
 
         E = C**D
         self.assertAlmostEqual(E.value, 745.1**0.34)
         self.assertEqual(E.unit, '1')
         self.assertAlmostEqual(E.uncert, np.sqrt((0.34 * 745.1**(0.34 - 1) * 53.9)**2 + (745.1**0.34 * np.log(745.1) * 0.01)**2))
 
-        with self.assertRaises(Exception) as context:
-            C_vec**D_vec
-        self.assertTrue('The exponent has to be a single number' in str(context.exception))
+        E_vec = C_vec**D_vec
+        np.testing.assert_equal(E_vec.value, [745.1 ** 0.34, 496.13**0.64, 120.54**0.87])
+        self.assertEqual(E_vec.unit, '1')
+        self.assertAlmostEqual(E_vec.uncert[0], np.sqrt((0.34 * 745.1**(0.34 - 1) * 53.9)**2 + (745.1**0.34 * np.log(745.1) * 0.01)**2))
 
+        
         F = A**2
         self.assertAlmostEqual(F.value, (12.3)**2)
         self.assertEqual(F.unit, 'L2/min2')
@@ -360,10 +362,13 @@ class test(unittest.TestCase):
         self.assertEqual(G.unit, '1')
         self.assertAlmostEqual(G.uncert, np.sqrt((2.54**0.34 * np.log(2.54) * 0.01)**2))
 
-        with self.assertRaises(Exception) as context:
-            2.54**D_vec
-        self.assertTrue('The exponent has to be a single number' in str(context.exception))
+        G_vec = 2.54**D_vec
+        np.testing.assert_equal(G_vec.value, [2.54**0.34, 2.54 **0.64 , 2.54**0.87])
+        self.assertEqual(G_vec.unit, '1')
+        self.assertAlmostEqual(G_vec.uncert[0], np.sqrt((2.54**0.34 * np.log(2.54) * 0.01)**2))
 
+        
+        
     def test_log(self):
         A = variable(12.3, 'L/min', uncert=2.6)
         C = variable(745.1, '1', uncert=53.9)
@@ -429,28 +434,28 @@ class test(unittest.TestCase):
             np.exp(A)
         self.assertTrue('The exponent can not have a unit' in str(context.exception))
 
-        with self.assertRaises(Exception) as context:
-            np.exp(A_vec)
-        self.assertTrue('The exponent has to be a single number' in str(context.exception))
-
+        c_vec = np.exp(C_vec)
+        np.testing.assert_equal(c_vec.value, [np.e**12.3, np.e**54.3, np.e**91.3])
+        self.assertEqual(c_vec.unit, '1')
+        self.assertEqual(c_vec.uncert[0], np.sqrt((np.e**12.3 * np.log(np.e) * 2.6)**2))
+        
         D = np.exp(C)
         self.assertAlmostEqual(D.value, np.e**12.3)
         self.assertEqual(D.unit, '1')
         self.assertAlmostEqual(D.uncert, np.sqrt((np.e**12.3 * np.log(np.e) * 5.39)**2))
 
         with self.assertRaises(Exception) as context:
-            np.exp(C_vec)
-        self.assertTrue('The exponent has to be a single number' in str(context.exception))
+            np.exp(A_vec)
+        self.assertTrue('The exponent can not have a unit' in str(context.exception))
 
     def testIndex(self):
         A = variable(12.3, 'L/min', uncert=2.6)
         A_vec = variable([12.3, 54.3, 91.3], 'L/min', uncert=[2.6, 5.4, 10.56])
 
-        a = A[0]
-        self.assertEqual(a.value, 12.3)
-        self.assertEqual(a.unit, 'L/min')
-        self.assertEqual(a.uncert, 2.6)
-
+        with self.assertRaises(Exception) as context:
+            a = A[0]
+        self.assertTrue("'scalarVariable' object is not subscriptable" in str(context.exception))
+        
         a_vec = A_vec[0, 1]
         np.testing.assert_equal(a_vec.value, [12.3, 54.3])
         self.assertEqual(a_vec.unit, 'L/min')
@@ -468,10 +473,10 @@ class test(unittest.TestCase):
 
         with self.assertRaises(Exception) as context:
             a = A[1]
-        self.assertTrue('Index out of bounds' in str(context.exception))
+        self.assertTrue("'scalarVariable' object is not subscriptable" in str(context.exception))
 
         with self.assertRaises(Exception) as context:
-            a = A[23]
+            a = A_vec[23]
         self.assertTrue('Index out of bounds' in str(context.exception))
 
     def testAddEqual(self):
@@ -917,20 +922,18 @@ class test(unittest.TestCase):
 
         with self.assertRaises(Exception) as context:
             2**A_vec
-        self.assertTrue('The exponent has to be a single number' in str(context.exception))
+        self.assertTrue('The exponent can not have a unit' in str(context.exception))
 
         with self.assertRaises(Exception) as context:
             2**B_vec
-        self.assertTrue('The exponent has to be a single number' in str(context.exception))
-
-        with self.assertRaises(Exception) as context:
-            2**C_vec
-        self.assertTrue('The exponent has to be a single number' in str(context.exception))
-
-        with self.assertRaises(Exception) as context:
-            2**D_vec
-        self.assertTrue('The exponent has to be a single number' in str(context.exception))
+        self.assertTrue('The exponent can not have a unit' in str(context.exception))
+     
+        d_vec = 2**D_vec
+        np.testing.assert_equal(d_vec.value, [2**0.34, 2**0.64, 2**0.87])
+        self.assertEqual(d_vec.unit, '1')
+        self.assertEqual(d_vec.uncert[0], np.sqrt((2**0.34 * np.log(2) * 0.01)**2 + (0.34 * 2**(0.34 - 1) * 0)**2))
 
+        
     def testPrettyPrint(self):
         a = variable(12.3, 'm')
         b = variable(12.3, 'm', 2.5)
@@ -1214,48 +1217,49 @@ class test(unittest.TestCase):
     def testCompare(self):
         a = variable(1, 'm')
         b = variable([2, 3, 4], 'm')
-        self.assertListEqual(a < b, [True, True, True])
-        self.assertEqual(a <= b, [True, True, True])
-        self.assertEqual(a > b, [False, False, False])
-        self.assertEqual(a >= b, [False, False, False])
-        self.assertEqual(a == b, [False, False, False])
-        self.assertEqual(a != b, [True, True, True])
+        np.testing.assert_equal(a < b, [True, True, True])
+        np.testing.assert_equal(a <= b, [True, True, True])
+        np.testing.assert_equal(a > b, [False, False, False])
+        np.testing.assert_equal(a >= b, [False, False, False])
+        np.testing.assert_equal(a == b, [False, False, False])
+        np.testing.assert_equal(a != b, [True, True, True])
 
         a = variable([2, 3, 4], 'm')
         b = variable(1, 'm')
-        self.assertListEqual(a < b, [False, False, False])
-        self.assertEqual(a <= b, [False, False, False])
-        self.assertEqual(a > b, [True, True, True])
-        self.assertEqual(a >= b, [True, True, True])
-        self.assertEqual(a == b, [False, False, False])
-        self.assertEqual(a != b, [True, True, True])
+        np.testing.assert_equal(a < b, [False, False, False])
+        np.testing.assert_equal(a <= b, [False, False, False])
+        np.testing.assert_equal(a > b, [True, True, True])
+        np.testing.assert_equal(a >= b, [True, True, True])
+        np.testing.assert_equal(a == b, [False, False, False])
+        np.testing.assert_equal(a != b, [True, True, True])
 
         a = variable([1, 2], 'm')
         b = variable([2, 3, 4], 'm')
         with self.assertRaises(Exception) as context:
             c = a < b
-        self.assertTrue("You cannot compare [1, 2] [m] and [2, 3, 4] [m] as they do not have the same length" in str(context.exception))
+        self.assertTrue("operands could not be broadcast together with shapes (2,) (3,)" in str(context.exception))
 
         with self.assertRaises(Exception) as context:
             c = a <= b
-        self.assertTrue("You cannot compare [1, 2] [m] and [2, 3, 4] [m] as they do not have the same length" in str(context.exception))
+        self.assertTrue("operands could not be broadcast together with shapes (2,) (3,)" in str(context.exception))
 
         with self.assertRaises(Exception) as context:
             c = a > b
-        self.assertTrue("You cannot compare [1, 2] [m] and [2, 3, 4] [m] as they do not have the same length" in str(context.exception))
+        self.assertTrue("operands could not be broadcast together with shapes (2,) (3,)" in str(context.exception))
 
         with self.assertRaises(Exception) as context:
             c = a >= b
-        self.assertTrue("You cannot compare [1, 2] [m] and [2, 3, 4] [m] as they do not have the same length" in str(context.exception))
+        self.assertTrue("operands could not be broadcast together with shapes (2,) (3,)" in str(context.exception))
 
         with self.assertRaises(Exception) as context:
             c = a == b
-        self.assertTrue("You cannot compare [1, 2] [m] and [2, 3, 4] [m] as they do not have the same length" in str(context.exception))
+        self.assertTrue("operands could not be broadcast together with shapes (2,) (3,)" in str(context.exception))
 
         with self.assertRaises(Exception) as context:
             c = a != b
-        self.assertTrue("You cannot compare [1, 2] [m] and [2, 3, 4] [m] as they do not have the same length" in str(context.exception))
-
+        self.assertTrue("operands could not be broadcast together with shapes (2,) (3,)" in str(context.exception))
+        
+        
         a = variable(1, 'm')
         b = variable(2, 'C')
         with self.assertRaises(Exception) as context:
@@ -1284,23 +1288,292 @@ class test(unittest.TestCase):
 
         a = variable([1, 2, 3], 'm')
         b = variable([2, 3, 4], 'm')
-        self.assertListEqual(a < b, [True, True, True])
-        self.assertEqual(a <= b, [True, True, True])
-        self.assertEqual(a > b, [False, False, False])
-        self.assertEqual(a >= b, [False, False, False])
-        self.assertEqual(a == b, [False, False, False])
-        self.assertEqual(a != b, [True, True, True])
+        np.testing.assert_equal(a < b, [True, True, True])
+        np.testing.assert_equal(a <= b, [True, True, True])
+        np.testing.assert_equal(a > b, [False, False, False])
+        np.testing.assert_equal(a >= b, [False, False, False])
+        np.testing.assert_equal(a == b, [False, False, False])
+        np.testing.assert_equal(a != b, [True, True, True])
         
         
         a = variable(10,'L/min')
         b = variable(1, 'm3/h')
-        self.assertEqual(a>b, False)
-        self.assertEqual(a<b, True)
-        self.assertEqual(a>=b, False)
-        self.assertEqual(a<=b, True)
-        self.assertEqual(a==b, False)
-        self.assertEqual(a!=b, True)
+        np.testing.assert_equal(a>b, False)
+        np.testing.assert_equal(a<b, True)
+        np.testing.assert_equal(a>=b, False)
+        np.testing.assert_equal(a<=b, True)
+        np.testing.assert_equal(a==b, False)
+        np.testing.assert_equal(a!=b, True)
 
+    def testSetitem(self):
+        A = variable(12.3, 'L/min', uncert=2.6)
+        B = variable(45, 'Pa', 1.2)
+        A_vec = variable([12.3, 54.3, 91.3], 'L/min', uncert=[2.6, 5.4, 10.56])
+
+        A_vec[1] = A
+        np.testing.assert_equal(A_vec.value, [12.3, 12.3, 91.3])
+        self.assertEqual(A_vec.unit, 'L/min')
+        np.testing.assert_equal(A_vec.uncert, [2.6, 2.6, 10.56])
+        
+        with self.assertRaises(Exception) as context:
+            A_vec[0] = B
+        self.assertTrue("You can not set an element of [12, 12, 90] +/- [3, 3, 10] [L/min] with 45 +/- 1 [Pa] as they do not have the same unit" in str(context.exception))
+
+        with self.assertRaises(Exception) as context:
+            A_vec[0] = A_vec
+        self.assertTrue("You can only set an element with a scalar variable" in str(context.exception))
+
+        with self.assertRaises(Exception) as context:
+            A[0] = B
+        self.assertTrue("'scalarVariable' object does not support item assignment" in str(context.exception))
+           
+    def testAppend(self):
+        A = variable(12.3, 'L/min', uncert=2.6)
+        B = variable(45, 'Pa', 1.2)
+        A_vec = variable([12.3, 54.3, 91.3], 'L/min', uncert=[2.6, 5.4, 10.56])
+
+        A_vec.append(A)
+        np.testing.assert_equal(A_vec.value, [12.3, 54.3, 91.3, 12.3])
+        self.assertEqual(A_vec.unit, 'L/min')
+        np.testing.assert_equal(A_vec.uncert, [2.6, 5.4, 10.56, 2.6])
+        
+        with self.assertRaises(Exception) as context:
+            A_vec.append(B)
+        self.assertTrue("You can not set an element of [12, 54, 90, 12] +/- [3, 5, 10, 3] [L/min] with 45 +/- 1 [Pa] as they do not have the same unit" in str(context.exception))
+
+        A_vec.append(A_vec)
+        np.testing.assert_equal(A_vec.value, [12.3, 54.3, 91.3, 12.3] * 2)
+        self.assertEqual(A_vec.unit, 'L/min')
+        np.testing.assert_equal(A_vec.uncert, [2.6, 5.4, 10.56, 2.6] * 2)
+        
+        with self.assertRaises(Exception) as context:
+            A.append(B)
+        self.assertTrue("'scalarVariable' object has no attribute 'append'" in str(context.exception))
+        
+    def testAddBel(self):
+        a = variable(11,'dB', 0.1)
+        b = variable(19,'dB',1.2)
+        c = a + b
+        self.assertEqual(c.value, 19.638920341433795986775635083534144311728776386508569289294)
+        self.assertEqual(c.unit, 'dB')
+        gradA = (10**(11/10)) / (10**(19/10) + 10**(11/10))
+        gradB = (10**(19/10)) / (10**(19/10) + 10**(11/10))
+        self.assertAlmostEqual(c.uncert, np.sqrt( (gradA * a.uncert)**2 + (gradB * b.uncert)**2))
+        
+        a = variable(11,'B', 0.1)
+        b = variable(19,'B',1.2)
+        c = a + b
+        self.assertEqual(c.value, 19.000000004342944797317794326113524021957351355250018803653068412)
+        self.assertEqual(c.unit, 'B')
+        gradA = (10**(11)) / (10**(19) + 10**(11))
+        gradB = (10**(19)) / (10**(19) + 10**(11))
+        self.assertAlmostEqual(c.uncert, np.sqrt( (gradA * a.uncert)**2 + (gradB * b.uncert)**2))
+        
+        a = variable(1.1,'B', 0.1)
+        b = variable(19,'dB',1.2)
+        c = a + b
+        self.assertAlmostEqual(c.value, 1.9638920341433795986775635083534144311728776386508569289294)
+        self.assertEqual(c.unit, 'B')
+        gradA = 10**1.1 / (10**(19/10) + 10**1.1)
+        gradB = 10**(19/10-1) / (10**(19/10) + 10**1.1)
+        self.assertAlmostEqual(c.uncert, np.sqrt( (gradA * a.uncert)**2 + (gradB * b.uncert)**2))
+        
+    def testSubtractBel(self):
+        a = variable(11,'dB', 0.1)
+        b = variable(19,'dB',1.2)
+        c = b - a
+        self.assertEqual(c.value, 18.250596325673850704123951198937009709734608031896818185442)
+        self.assertEqual(c.unit, 'dB')
+        gradA = -(10**(11/10)) / (10**(19/10) - 10**(11/10))
+        gradB = (10**(19/10)) / (10**(19/10) - 10**(11/10))
+        self.assertAlmostEqual(c.uncert, np.sqrt( (gradA * a.uncert)**2 + (gradB * b.uncert)**2))
+        
+        a = variable(11,'B', 0.1)
+        b = variable(19,'B',1.2)
+        c = b - a
+        self.assertEqual(c.value, 18.99999999565705515925275748356129104145734723683018994643533534)
+        self.assertEqual(c.unit, 'B')
+        gradA = -(10**(11)) / (10**(19) - 10**(11))
+        gradB = (10**(19)) / (10**(19) - 10**(11))
+        self.assertAlmostEqual(c.uncert, np.sqrt( (gradA * a.uncert)**2 + (gradB * b.uncert)**2))
+        
+        a = variable(1.1,'B', 0.1)
+        b = variable(19,'dB',1.2)
+        c = b-a
+        self.assertAlmostEqual(c.value, 18.250596325673850704123951198937009709734608031896818185442)
+        self.assertEqual(c.unit, 'dB')
+        gradA = -10**(1.1+1) / (10**(19/10) - 10**1.1)
+        gradB = 10**(19/10) / (10**(19/10) - 10**1.1)
+        self.assertAlmostEqual(c.uncert, np.sqrt( (gradA * a.uncert)**2 + (gradB * b.uncert)**2))
+    
+    def testAddNeper(self):
+        a = variable(1.1,'Np', 1.2)
+        b = variable(1.9,'Np', 0.1)
+        c = a + b
+        gradA =np.exp(2*1.1) / (np.exp(2*1.1) + np.exp(2*1.9))
+        gradB = np.exp(2*1.9) / (np.exp(2*1.1) + np.exp(2*1.9))
+        self.assertAlmostEqual(c.value, 1.9919503704442)
+        self.assertEqual(c.unit, 'Np')
+        self.assertAlmostEqual(c.uncert, np.sqrt( (gradA * 1.2)**2 + (gradB * 0.1)**2))
+        
+        a = variable(11,'dNp', 0.1)
+        b = variable(19,'dNp', 1.2)
+        c = a + b
+        self.assertEqual(c.value, 19.919503704441694148537476059644226712824512622876065)
+        self.assertEqual(c.unit, 'dNp')
+        gradA = np.exp(11/5) / ((np.exp(11/5) + np.exp(19/5)))
+        gradB = np.exp(19/5) / ((np.exp(11/5) + np.exp(19/5)))
+        self.assertAlmostEqual(c.uncert, np.sqrt( (gradA * a.uncert)**2 + (gradB * b.uncert)**2))
+        
+        a = variable(1.1,'B', 0.2)
+        b = variable(1.9,'Np',0.1)
+        c = a + b
+        self.assertAlmostEqual(c.value, 1.758082147187876468991064264007183585955484366785)
+        self.assertEqual(c.unit, 'B')
+        gradA = 10**1.1 / (np.exp(2*1.9) + 10**1.1)
+        gradB = 2 * np.exp(2*1.9) / (np.log(10) * (10**1.1 + np.exp(2*1.9)))
+        self.assertAlmostEqual(c.uncert, np.sqrt( (gradA * a.uncert)**2 + (gradB * b.uncert)**2))
+
+    def testSubtractNeper(self):
+        a = variable(1.1,'Np', 1.2)
+        b = variable(1.9,'Np', 0.1)
+        c = b - a
+        gradA = -np.exp(2*1.1) / (-np.exp(2*1.1) + np.exp(2*1.9))
+        gradB = np.exp(2*1.9) / (-np.exp(2*1.1) + np.exp(2*1.9))
+        self.assertAlmostEqual(c.value, 1.7872414933794011376350282497774605052189199203232206053472)
+        self.assertEqual(c.unit, 'Np')
+        self.assertAlmostEqual(c.uncert, np.sqrt( (gradA * 1.2)**2 + (gradB * 0.1)**2))
+        
+        a = variable(11,'dNp', 0.1)
+        b = variable(19,'dNp', 1.2)
+        c = b - a
+        self.assertEqual(c.value, 17.872414933794011376350282497774605052189199203232206053472)
+        self.assertEqual(c.unit, 'dNp')
+        gradA = -np.exp(11/5) / ((-np.exp(11/5) + np.exp(19/5)))
+        gradB = np.exp(19/5) / ((-np.exp(11/5) + np.exp(19/5)))
+        self.assertAlmostEqual(c.uncert, np.sqrt( (gradA * a.uncert)**2 + (gradB * b.uncert)**2))
+        
+        a = variable(1.1,'B', 0.2)
+        b = variable(1.9,'Np',0.1)
+        c = b - a
+        self.assertAlmostEqual(c.value, 1.7346138119351200779277098049685724168821500468817797823749)
+        self.assertEqual(c.unit, 'Np')
+        gradA = - (2**(1.1-1) * 5**1.1 * np.log(10)) / (np.exp(2 * 1.9) - 10**1.1)
+        gradB =  np.exp(2*1.9) / (-10**1.1 + np.exp(2*1.9))
+        self.assertAlmostEqual(c.uncert, np.sqrt( (gradA * a.uncert)**2 + (gradB * b.uncert)**2))
+
+    def testAddOctave(self):
+        a = variable(11,'oct', 0.1)
+        b = variable(19,'oct',1.2)
+        c = a + b
+        self.assertEqual(c.value, 19.005624549193878106919859102674066601721109681538352035907295778)
+        self.assertEqual(c.unit, 'oct')
+        gradA = (2**(11)) / (2**(19) + 2**(11))
+        gradB = (2**(19)) / (2**(19) + 2**(11))
+        self.assertAlmostEqual(c.uncert, np.sqrt( (gradA * a.uncert)**2 + (gradB * b.uncert)**2))
+        
+        a = variable(11,'doct', 0.1)
+        b = variable(19,'doct',1.2)
+        c = a + b
+        self.assertEqual(c.value, 25.547555540454389776996741016863742223173494327085729223977)
+        self.assertEqual(c.unit, 'doct')
+        gradA = (2**(11/10)) / (2**(19/10) + 2**(11/10))
+        gradB = (2**(19/10)) / (2**(19/10) + 2**(11/10))
+        self.assertAlmostEqual(c.uncert, np.sqrt( (gradA * a.uncert)**2 + (gradB * b.uncert)**2))
+        
+        a = variable(1.1,'oct', 0.1)
+        b = variable(19,'doct',1.2)
+        c = a + b
+        self.assertAlmostEqual(c.value, 2.5547555540454389776996741016863742223173494327085729223977)
+        self.assertEqual(c.unit, 'oct')
+        gradA = 2**1.1 / (2**(19/10) + 2**1.1)
+        gradB = 1 / (10*(2**(1.1 - 19/10) + 1))
+        self.assertAlmostEqual(c.uncert, np.sqrt( (gradA * a.uncert)**2 + (gradB * b.uncert)**2))
+        
+    def testSubtractOctave(self):
+        a = variable(11,'oct', 0.1)
+        b = variable(19,'oct',1.2)
+        c = b - a
+        self.assertEqual(c.value, 18.994353436858857937578124384247611038635913083061882360637118114)
+        self.assertEqual(c.unit, 'oct')
+        gradA = -(2**(11)) / (2**(19) - 2**(11))
+        gradB = (2**(19)) / (2**(19) - 2**(11))
+        self.assertAlmostEqual(c.uncert, np.sqrt( (gradA * a.uncert)**2 + (gradB * b.uncert)**2))
+        
+        a = variable(11,'doct', 0.1)
+        b = variable(19,'doct',1.2)
+        c = b - a
+        self.assertAlmostEqual(c.value, 6.677423233234791893663882614756435176500756327730140063397)
+        self.assertEqual(c.unit, 'doct')
+        gradA = -(2**(11/10)) / (2**(19/10) - 2**(11/10))
+        gradB = (2**(19/10)) / (2**(19/10) - 2**(11/10))
+        self.assertAlmostEqual(c.uncert, np.sqrt( (gradA * a.uncert)**2 + (gradB * b.uncert)**2))
+        
+        a = variable(1.1,'oct', 0.1)
+        b = variable(19,'doct',1.2)
+        c = b - a
+        self.assertAlmostEqual(c.value, 6.677423233234791893663882614756435176500756327730140063397)
+        self.assertEqual(c.unit, 'doct')
+        gradA = -5 * 2**(1.1+1) / (2**(19/10) - 2**1.1) 
+        gradB = 2**(19/10) / (2**(19/10) - 2**1.1)
+        self.assertAlmostEqual(c.uncert, np.sqrt( (gradA * a.uncert)**2 + (gradB * b.uncert)**2))
+          
+    def testAddDecade(self):
+        a = variable(11,'ddec', 0.1)
+        b = variable(19,'ddec',1.2)
+        c = a + b
+        self.assertEqual(c.value, 19.638920341433795986775635083534144311728776386508569289294)
+        self.assertEqual(c.unit, 'ddec')
+        gradA = (10**(11/10)) / (10**(19/10) + 10**(11/10))
+        gradB = (10**(19/10)) / (10**(19/10) + 10**(11/10))
+        self.assertAlmostEqual(c.uncert, np.sqrt( (gradA * a.uncert)**2 + (gradB * b.uncert)**2))
+        
+        a = variable(11,'dec', 0.1)
+        b = variable(19,'dec',1.2)
+        c = a + b
+        self.assertEqual(c.value, 19.000000004342944797317794326113524021957351355250018803653068412)
+        self.assertEqual(c.unit, 'dec')
+        gradA = (10**(11)) / (10**(19) + 10**(11))
+        gradB = (10**(19)) / (10**(19) + 10**(11))
+        self.assertAlmostEqual(c.uncert, np.sqrt( (gradA * a.uncert)**2 + (gradB * b.uncert)**2))
+        
+        a = variable(1.1,'dec', 0.1)
+        b = variable(19,'ddec',1.2)
+        c = a + b
+        self.assertAlmostEqual(c.value, 1.9638920341433795986775635083534144311728776386508569289294)
+        self.assertEqual(c.unit, 'dec')
+        gradA = 10**1.1 / (10**(19/10) + 10**1.1)
+        gradB = 10**(19/10-1) / (10**(19/10) + 10**1.1)
+        self.assertAlmostEqual(c.uncert, np.sqrt( (gradA * a.uncert)**2 + (gradB * b.uncert)**2))
+        
+    def testSubtractDecade(self):
+        a = variable(11,'ddec', 0.1)
+        b = variable(19,'ddec',1.2)
+        c = b - a
+        self.assertEqual(c.value, 18.250596325673850704123951198937009709734608031896818185442)
+        self.assertEqual(c.unit, 'ddec')
+        gradA = -(10**(11/10)) / (10**(19/10) - 10**(11/10))
+        gradB = (10**(19/10)) / (10**(19/10) - 10**(11/10))
+        self.assertAlmostEqual(c.uncert, np.sqrt( (gradA * a.uncert)**2 + (gradB * b.uncert)**2))
+        
+        a = variable(11,'dec', 0.1)
+        b = variable(19,'dec',1.2)
+        c = b - a
+        self.assertEqual(c.value, 18.99999999565705515925275748356129104145734723683018994643533534)
+        self.assertEqual(c.unit, 'dec')
+        gradA = -(10**(11)) / (10**(19) - 10**(11))
+        gradB = (10**(19)) / (10**(19) - 10**(11))
+        self.assertAlmostEqual(c.uncert, np.sqrt( (gradA * a.uncert)**2 + (gradB * b.uncert)**2))
+        
+        a = variable(1.1,'dec', 0.1)
+        b = variable(19,'ddec',1.2)
+        c = b-a
+        self.assertAlmostEqual(c.value, 18.250596325673850704123951198937009709734608031896818185442)
+        self.assertEqual(c.unit, 'ddec')
+        gradA = -10**(1.1+1) / (10**(19/10) - 10**1.1)
+        gradB = 10**(19/10) / (10**(19/10) - 10**1.1)
+        self.assertAlmostEqual(c.uncert, np.sqrt( (gradA * a.uncert)**2 + (gradB * b.uncert)**2))
+      
 
 if __name__ == '__main__':
     unittest.main()
