@@ -1,7 +1,7 @@
 import numpy as np
 try:
-    from .unitSystem import _unitConversion
-    from .__init__ import knownPrefixes, knownUnits, knownCharacters, knownUnitsDict, baseUnit
+    from pyees.unitSystem import _unitConversion
+    from pyees.__init__ import knownPrefixes, knownUnits, knownCharacters, knownUnitsDict, baseUnit
 except ImportError:
     from unitSystem import _unitConversion, getDicts
     knownUnits, knownCharacters, knownUnitsDict, knownPrefixes, baseUnit = getDicts()
