@@ -1,7 +1,7 @@
 from copy import deepcopy
 import numpy as np
 try:
-    from .unit import unit
+    from pyees.unit import unit
 except ImportError:
     from unit import unit
     
